Module: Bumblebee
- Defined in:
- lib/bumblebee/column.rb,
lib/bumblebee/version.rb,
lib/bumblebee/template.rb,
lib/bumblebee/bumblebee.rb
Overview
The top-level module provides the two main methods for convenience. You can also consume these in a more OOP way using the Template class or a more procedural way using these.
Defined Under Namespace
Constant Summary collapse
- VERSION =
'2.0.0'
Class Method Summary collapse
- .generate_csv(columns, objects, options = {}) ⇒ Object
- .parse_csv(columns, string, options = {}) ⇒ Object
Class Method Details
.generate_csv(columns, objects, options = {}) ⇒ Object
22 23 24 |
# File 'lib/bumblebee/bumblebee.rb', line 22 def generate_csv(columns, objects, = {}) ::Bumblebee::Template.new(columns).generate_csv(objects, ) end |